==> ugene_34.0+dfsg.orig.tar.xz: ugene-34.0/src/corelibs/U2View/src/ov_msa/helpers/McaRowHeightController.cpp <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2020 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#include "McaRowHeightController.h"
#include "ov_msa/McaEditor.h"
#include "ov_msa/view_rendering/SequenceWithChromatogramAreaRenderer.h"

namespace U2 {

McaRowHeightController::McaRowHeightController(McaEditorWgt *mcaEditorWgt)
    : RowHeightController(mcaEditorWgt)
{

}

int McaRowHeightController::getRowHeightByMaIndex(int maRowIndex) const {
    const int fontHeight = QFontMetrics(ui->getEditor()->getFont(), ui).height();

    int rowHeigth = fontHeight;
    if (!ui->getCollapseModel()->isGroupWithMaRowIndexCollapsed(maRowIndex)) {
        rowHeigth += SequenceWithChromatogramAreaRenderer::CHROMATOGRAM_MAX_HEIGHT;
    }
    rowHeigth = qRound(rowHeigth * ui->getEditor()->zoomMult);
    return rowHeigth;
}

}   // namespace U2

==> ugene_40.1+dfsg.orig.tar.xz: ugene-40.1/src/corelibs/U2View/src/ov_msa/helpers/McaRowHeightController.cpp <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#include "McaRowHeightController.h"

#include "ov_msa/McaEditor.h"
#include "ov_msa/view_rendering/SequenceWithChromatogramAreaRenderer.h"

namespace U2 {

McaRowHeightController::McaRowHeightController(McaEditorWgt *mcaEditorWgt)
    : RowHeightController(mcaEditorWgt) {
}

int McaRowHeightController::getRowHeightByMaIndex(int maRowIndex) const {
    MaEditor *editor = ui->getEditor();
    const int fontHeight = QFontMetrics(editor->getFont(), ui).height();

    int rowHeigth = fontHeight;
    if (!editor->getCollapseModel()->isGroupWithMaRowIndexCollapsed(maRowIndex)) {
        rowHeigth += SequenceWithChromatogramAreaRenderer::CHROMATOGRAM_MAX_HEIGHT;
    }
    rowHeigth = qRound(rowHeigth * editor->zoomMult);
    return rowHeigth;
}

}  // namespace U2
